summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirstatsettings.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit44af2b7aa26c61f2f059acc7a9726319cacaabcf (patch)
tree09c93f4a6fdef07c083e731d9f327850e83a6bf5 /kdirstat/kdirstatsettings.h
parentb8e1a56a901671dbd336c9bfd129dfb72a0cc41f (diff)
downloadkdirstat-44af2b7aa26c61f2f059acc7a9726319cacaabcf.tar.gz
kdirstat-44af2b7aa26c61f2f059acc7a9726319cacaabcf.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kdirstatsettings.h')
-rw-r--r--kdirstat/kdirstatsettings.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kdirstat/kdirstatsettings.h b/kdirstat/kdirstatsettings.h
index 078860a..f0a5c9e 100644
--- a/kdirstat/kdirstatsettings.h
+++ b/kdirstat/kdirstatsettings.h
@@ -63,8 +63,8 @@ namespace KDirStat
/**
* Constructor.
*
* Notice there is no tqparent widget passed but the application's main
* window so its functions can be accessed. The tqparent of this widget
* is always 0 since this is a dialog.
**/
@@ -90,7 +90,7 @@ namespace KDirStat
* certainly not be the way to go.
*
* This overwritten show() method sends that @ref aboutToShow() signal
* before calling the tqparent class show() method.
**/
virtual void show();
@@ -153,7 +153,7 @@ namespace KDirStat
* e.g., apply(), setup(), revertToDefaults().
**/
KSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent );
+ TQWidget * parent );
/**
* Destructor.
@@ -227,7 +227,7 @@ namespace KDirStat
* Constructor
**/
KTreeColorsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -306,7 +306,7 @@ namespace KDirStat
* Constructor
**/
KCleanupPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -414,7 +414,7 @@ namespace KDirStat
/**
* Constructor.
**/
- KCleanupListBox( TQWidget * tqparent = 0 );
+ KCleanupListBox( TQWidget * parent = 0 );
/**
* Destructor.
@@ -519,7 +519,7 @@ namespace KDirStat
/**
* Constructor
**/
- KCleanupPropertiesPage( TQWidget * tqparent,
+ KCleanupPropertiesPage( TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -579,7 +579,7 @@ namespace KDirStat
* Constructor
**/
KGeneralSettingsPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -649,7 +649,7 @@ namespace KDirStat
* Constructor
**/
KTreemapPage( KSettingsDialog * dialog,
- TQWidget * tqparent,
+ TQWidget * parent,
KDirStatApp * mainWin );
/**
@@ -737,12 +737,12 @@ namespace KDirStat
/**
* Add a horizontal stretch widget to take all excess space.
**/
-void addHStretch( TQWidget * tqparent );
+void addHStretch( TQWidget * parent );
/**
* Add a vertical stretch widget to take all excess space.
**/
-void addVStretch( TQWidget * tqparent );
+void addVStretch( TQWidget * parent );
@@ -63,8 +63,8 @@ namespace KDirStat
* Constructor.
*
- * Notice there is no tqparent widget passed but the application's main
- * window so its functions can be accessed. The tqparent of this widget
+ * Notice there is no parent widget passed but the application's main
+ * window so its functions can be accessed. The parent of this widget
* is always 0 since this is a dialog.
**/
@@ -90,7 +90,7 @@ namespace KDirStat
*
* This overwritten show() method sends that @ref aboutToShow() signal
- * before calling the tqparent class show() method.
+ * before calling the parent class show() method.
**/
virtual void show();